# contspy

[![gh-actions](https://img.shields.io/github/workflow/status/ajacquey/contspy/ci?style=flat-square)](https://github.com/ajacquey/contspy/actions?query=workflow%3Aci)
[![CircleCI](https://img.shields.io/circleci/project/github/ajacquey/contspy/master.svg?style=flat-square)](https://circleci.com/gh/ajacquey/contspy/tree/master)
[![travis](https://img.shields.io/travis/ajacquey/contspy.svg?style=flat-square)](https://travis-ci.org/ajacquey/contspy)
[![codecov](https://img.shields.io/codecov/c/github/ajacquey/contspy.svg?style=flat-square)](https://codecov.io/gh/ajacquey/contspy)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](https://github.com/psf/black)
[![awesome](https://img.shields.io/badge/awesome-yes-8209ba.svg?style=flat-square)](https://github.com/ajacquey/contspy)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/contspy.svg?style=flat-square)](https://pypi.org/pypi/contspy/)
[![PyPi Version](https://img.shields.io/pypi/v/contspy.svg?style=flat-square)](https://pypi.org/project/contspy)
[![GitHub stars](https://img.shields.io/github/stars/ajacquey/contspy.svg?logo=github&label=Stars&logoColor=white&style=flat-square)](https://github.com/ajacquey/contspy)
[![PyPi downloads](https://img.shields.io/pypi/dm/contspy.svg?style=flat-square)](https://pypistats.org/packages/contspy)

Contspy provides several tools to perform numerical continuation for partial differential equations (PDEs) using the spectral elements method.

### Testing

To run the contspy unit tests, check out this repository and type
```
pytest
```

### License

contspy is published under the [MIT license](https://en.wikipedia.org/wiki/MIT_License).

### Acknowledgements

